@@ -5,7 +5,7 @@ use strict ;
 use App::Framework ;
 
 # VERSION
-our $VERSION = '1.001' ;
+our $VERSION = '1.002' ;
 
 
 	# Create application and run it
@@ -25,8 +25,21 @@ sub run
 	# Get source/dest dirs
 	my ($src_dir, $backup_dir) = @{$app->arglist()};
 	
+	# options
+	my %opts = $app->options() ;
+
+	if ($opts{array})
+	{
+		$app->prt_data("Array option=", $opts{array}) ;
+	}
+	if ($opts{hash})
+	{
+		$app->prt_data("Hash option=", $opts{hash}) ;
+	}
+
 	
 	# do something useful....
+	
 }
 
 
@@ -58,6 +71,28 @@ src_dir:id backup_dir:id
 
 Specify the database name to use
 
+-int=i		An integer
+
+Example of integer option
+
+-float=f	An float
+
+Example of float option
+
+-array=s@	An array
+
+Example of an array option
+
+-hash=s%	A hash
+
+Example of a hash option
+
+
+-log=s		Override the log [default=tmp.log]
+
+Example of replacing the default log option
+
+
 [DESCRIPTION]
 
 B<$name> expects a source directory and destination directory to be specified. If not, then
