@@ -85,14 +85,9 @@ sub new
 
 	my $class = ref($obj) || $obj ;
 
-	# Need to look 3 levels higher than this wrapper i.e. look at this wrapper's caller
-	# If this object is being used as a base for another object then use the '_caller' arg specified
-	my $call_level = delete $args{'_caller'} || 3 ;
-
 	# Create object
 	my $this = $class->SUPER::new(
 		%args, 
-		'_caller'=>$call_level,	
 	) ;
 
 	return($this) ;
